Validador class

Constructors

Validador()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Validar v, {String msg = DEFAULT_MESSAGE}) → Validador
equals(String value, {String msg = DEFAULT_MESSAGE}) → Validador
isTrue(bool boolValue, {String msg = DEFAULT_MESSAGE}) → Validador
maxLength(int max, {String msg = DEFAULT_MESSAGE}) → Validador
maxVal(int max, {String msg = DEFAULT_MESSAGE}) → Validador
minLength(int min, {String msg = DEFAULT_MESSAGE}) → Validador
minVal(int min, {String msg = DEFAULT_MESSAGE}) → Validador
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validar(String? valor, {dynamic clearNoNumber = false, dynamic seNulo}) → String?
valido(String? valor, {dynamic clearNoNumber = false, dynamic seNulo}) → String?

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DEFAULT_MESSAGE → const String